Documentation
¶
Overview ¶
Package xfail provides a testing helper for expected test failures.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func XFail ¶
XFail returns a new testing.TB instance that expects the test to fail for the given reason.
At the end of the test, if it was marked as failed using non-fatal methods Fail, Error, or Errorf, it will pass instead. If it wasn't marked as failed, it will fail so that the XFail call can be removed. Fatal methods FailNow, Fatal, or Fatalf will skip the rest of the test instead.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.